.. modoboa-stats documentation master file, created by
   sphinx-quickstart on Sun Apr  5 10:08:08 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to modoboa-stats's documentation!
=========================================

This plugin collects various metrics on your server and displays nice
graphics. It uses RRD files to store data (see `rrdtool
<http://oss.oetiker.ch/rrdtool/>`_) and then generates graphics `c3.js
<http://c3js.org/>`_.

Contents:

.. toctree::
   :maxdepth: 2

   setup
